@@ -137,24 +137,33 @@ impl OwnedFd {
     pub fn try_clone(&self) -> std::io::Result<Self> {
         #[cfg(feature = "close")]
         {
-            // We want to atomically duplicate this file descriptor and set the
-            // CLOEXEC flag, and currently that's done via F_DUPFD_CLOEXEC. This
-            // is a POSIX flag that was added to Linux in 2.6.24.
-            #[cfg(not(target_os = "espidf"))]
-            let cmd = libc::F_DUPFD_CLOEXEC;
+            #[cfg(unix)]
+            {
+                // We want to atomically duplicate this file descriptor and set the
+                // CLOEXEC flag, and currently that's done via F_DUPFD_CLOEXEC. This
+                // is a POSIX flag that was added to Linux in 2.6.24.
+                #[cfg(not(target_os = "espidf"))]
+                let cmd = libc::F_DUPFD_CLOEXEC;
 
-            // For ESP-IDF, F_DUPFD is used instead, because the CLOEXEC semantics
-            // will never be supported, as this is a bare metal framework with
-            // no capabilities for multi-process execution.  While F_DUPFD is also
-            // not supported yet, it might be (currently it returns ENOSYS).
-            #[cfg(target_os = "espidf")]
-            let cmd = libc::F_DUPFD;
+                // For ESP-IDF, F_DUPFD is used instead, because the CLOEXEC semantics
+                // will never be supported, as this is a bare metal framework with
+                // no capabilities for multi-process execution.  While F_DUPFD is also
+                // not supported yet, it might be (currently it returns ENOSYS).
+                #[cfg(target_os = "espidf")]
+                let cmd = libc::F_DUPFD;
 
-            let fd = match unsafe { libc::fcntl(self.as_raw_fd(), cmd, 0) } {
-                -1 => return Err(std::io::Error::last_os_error()),
-                fd => fd,
-            };
-            Ok(unsafe { Self::from_raw_fd(fd) })
+                let fd = match unsafe { libc::fcntl(self.as_raw_fd(), cmd, 0) } {
+                    -1 => return Err(std::io::Error::last_os_error()),
+                    fd => fd,
+                };
+
+                Ok(unsafe { Self::from_raw_fd(fd) })
+            }
+
+            #[cfg(target_os = "wasi")]
+            {
+                unreachable!("try_clone is not yet suppported on wasi");
+            }
         }
 
         // If the `close` feature is disabled, we expect users to avoid cloning
